@@ -6,7 +6,7 @@ import nipype.interfaces.fsl as fsl
 import nipype.interfaces.spm as spm
 
 from ..nodes.segment import (AtroposN4, BinaryFillHoles, merge_masks,
-                             split_indexed_mask)
+                             split_indexed_mask, copy_header, compute_5tt)
 
 from ..utils.misc import (gunzip, get_elem, merge_3_elem_to_list)
 
@@ -173,6 +173,39 @@ def create_segment_atropos_pipe(params={}, name="segment_atropos_pipe",
 
     if "use_priors" in params.keys():
 
+        # copying header from img to csf_prior_file
+        copy_header_to_csf = pe.Node(niu.Function(
+            input_names=['ref_img', 'img_to_modify'],
+            output_names=['modified_img'],
+            function=copy_header), name='copy_header_to_csf')
+
+        segment_pipe.connect(inputnode, "brain_file",
+                             copy_header_to_csf, "ref_img")
+        segment_pipe.connect(inputnode, 'csf_prior_file',
+                             copy_header_to_csf, "img_to_modify")
+
+        # copying header from img to gm_prior_file
+        copy_header_to_gm = pe.Node(niu.Function(
+            input_names=['ref_img', 'img_to_modify'],
+            output_names=['modified_img'],
+            function=copy_header), name='copy_header_to_gm')
+
+        segment_pipe.connect(inputnode, "brain_file",
+                             copy_header_to_gm, "ref_img")
+        segment_pipe.connect(inputnode, 'gm_prior_file',
+                             copy_header_to_gm, "img_to_modify")
+
+        # copying header from img to wm_prior_file
+        copy_header_to_wm = pe.Node(niu.Function(
+            input_names=['ref_img', 'img_to_modify'],
+            output_names=['modified_img'],
+            function=copy_header), name='copy_header_to_wm')
+
+        segment_pipe.connect(inputnode, "brain_file",
+                             copy_header_to_wm, "ref_img")
+        segment_pipe.connect(inputnode, 'wm_prior_file',
+                             copy_header_to_wm, "img_to_modify")
+
         # merging priors as a list
         merge_3_elem = pe.Node(niu.Function(
             input_names=['elem1', 'elem2', 'elem3'],
@@ -180,10 +213,12 @@ def create_segment_atropos_pipe(params={}, name="segment_atropos_pipe",
             function=merge_3_elem_to_list), name='merge_3_elem')
 
         # was like this before (1 -> csf, 2 -> gm, 3 -> wm, to check)
-        segment_pipe.connect(inputnode, 'csf_prior_file', merge_3_elem, "elem1")
-        segment_pipe.connect(inputnode, 'gm_prior_file', merge_3_elem, "elem2")
-        segment_pipe.connect(inputnode, 'wm_prior_file', merge_3_elem, "elem3")
-
+        segment_pipe.connect(copy_header_to_csf, 'modified_img',
+                             merge_3_elem, "elem1")
+        segment_pipe.connect(copy_header_to_gm, 'modified_img',
+                             merge_3_elem, "elem2")
+        segment_pipe.connect(copy_header_to_wm, 'modified_img',
+                             merge_3_elem, "elem3")
     # Atropos
     seg_at = NodeParams(AtroposN4(),
                         params=parse_key(params, "Atropos"),
@@ -228,6 +263,30 @@ def create_segment_atropos_pipe(params={}, name="segment_atropos_pipe",
     return segment_pipe
 
 
+def create_5tt_pipe(params={}, name="export_5tt_pipe"):
+
+    # creating pipeline
+    export_5tt_pipe = pe.Workflow(name=name)
+
+    # creating inputnode
+    inputnode = pe.Node(
+        niu.IdentityInterface(
+            fields=["gm_file", "wm_file", "csf_file"]),
+        name='inputnode')
+
+    export_5tt = pe.Node(
+        niu.Function(input_names=["gm_file", "wm_file", "csf_file"],
+                     output_names=["gen_5tt_file"],
+                     function=compute_5tt),
+        name="export_5tt")
+
+    export_5tt_pipe.connect(inputnode, 'gm_file', export_5tt, 'gm_file')
+    export_5tt_pipe.connect(inputnode, 'wm_file', export_5tt, 'wm_file')
+    export_5tt_pipe.connect(inputnode, 'csf_file', export_5tt, 'csf_file')
+
+    return export_5tt_pipe
+
+
 ###############################################################################
 # old segment, originally from SPM8
 ###############################################################################
@@ -391,8 +450,8 @@ def create_native_old_segment_pipe(params_template, params={},
 
     # Creating inputnode
     inputnode = pe.Node(
-        niu.IdentityInterface(fields=['T1', 'indiv_params', "native_gm",
-                                      "native_wm", "native_csf"]),
+        niu.IdentityInterface(
+            fields=['T1', 'indiv_params', "native_T1", "inv_transfo_file"]),
         name='inputnode'
     )
 
@@ -407,42 +466,88 @@ def create_native_old_segment_pipe(params_template, params={},
 
     seg_pipe.connect(inputnode, 'T1', unzip, 'zipped_file')
 
-    # merging priors as a list
-    merge_native_tissues = pe.Node(niu.Function(
-        input_names=['elem1', 'elem2', 'elem3'],
-        output_names=['merged_list'],
-        function=merge_3_elem_to_list), name='merge_native_tissues')
-
-    seg_pipe.connect(inputnode, 'native_gm', merge_native_tissues, "elem1")
-    seg_pipe.connect(inputnode, 'native_wm', merge_native_tissues, "elem2")
-    seg_pipe.connect(inputnode, 'native_csf', merge_native_tissues, "elem3")
-
     # Segment in to 6 tissues
     segment = NodeParams(spm.Segment(),
                          params=parse_key(params, "segment"),
                          name="old_segment")
 
-    seg_pipe.connect(merge_native_tissues, 'merged_list',
-                     segment, 'tissue_prob_maps')
+    segment.inputs.tissue_prob_maps = [params_template["template_gm"],
+                                       params_template["template_wm"],
+                                       params_template["template_csf"]]
 
     seg_pipe.connect(unzip, 'unzipped_file', segment, 'data')
 
-    # Threshold GM, WM and CSF
-    thd_nodes = {}
-    for tissue in ['gm', 'wm', 'csf']:
+    # gm
+    register_gm_to_nat = pe.Node(fsl.ApplyXFM(), name="register_gm_to_nat")
+    register_gm_to_nat.inputs.output_type = "NIFTI_GZ"  # for SPM segment
 
-        tmp_node = NodeParams(fsl.Threshold(),
-                              params=parse_key(params, "threshold_" + tissue),
-                              name="threshold_" + tissue)
+    seg_pipe.connect(segment, 'native_gm_image',
+                     register_gm_to_nat, 'in_file')
 
-        seg_pipe.connect(segment, 'native_' + tissue + '_image',
-                         tmp_node, 'in_file')
+    seg_pipe.connect(inputnode, 'native_T1',
+                     register_gm_to_nat, 'reference')
 
-        seg_pipe.connect(
-            inputnode, ('indiv_params', parse_key, "threshold_" + tissue),
-            tmp_node, "indiv_params")
+    seg_pipe.connect(inputnode, 'inv_transfo_file',
+                     register_gm_to_nat, "in_matrix_file")
 
-        thd_nodes[tissue] = tmp_node
+    # wm
+    register_wm_to_nat = pe.Node(fsl.ApplyXFM(), name="register_wm_to_nat")
+    register_wm_to_nat.inputs.output_type = "NIFTI_GZ"  # for SPM segment
+
+    seg_pipe.connect(segment, 'native_wm_image',
+                     register_wm_to_nat, 'in_file')
+
+    seg_pipe.connect(inputnode, 'native_T1',
+                     register_wm_to_nat, 'reference')
+
+    seg_pipe.connect(inputnode, 'inv_transfo_file',
+                     register_wm_to_nat, "in_matrix_file")
+
+    # csf
+    register_csf_to_nat = pe.Node(fsl.ApplyXFM(), name="register_csf_to_nat")
+    register_csf_to_nat.inputs.output_type = "NIFTI_GZ"  # for SPM segment
+
+    seg_pipe.connect(segment, 'native_csf_image',
+                     register_csf_to_nat, 'in_file')
+
+    seg_pipe.connect(inputnode, 'native_T1',
+                     register_csf_to_nat, 'reference')
+
+    seg_pipe.connect(inputnode, 'inv_transfo_file',
+                     register_csf_to_nat, "in_matrix_file")
+
+    # threshold_gm
+    threshold_gm = NodeParams(fsl.Threshold(),
+                              params=parse_key(params, "threshold_gm"),
+                              name="threshold_gm")
+
+    seg_pipe.connect(register_gm_to_nat, 'out_file', threshold_gm, 'in_file')
+
+    seg_pipe.connect(
+        inputnode, ('indiv_params', parse_key, "threshold_gm"),
+        threshold_gm, "indiv_params")
+
+    # threshold_wm
+    threshold_wm = NodeParams(fsl.Threshold(),
+                              params=parse_key(params, "threshold_wm"),
+                              name="threshold_wm")
+
+    seg_pipe.connect(register_wm_to_nat, 'out_file', threshold_wm, 'in_file')
+
+    seg_pipe.connect(
+        inputnode, ('indiv_params', parse_key, "threshold_wm"),
+        threshold_wm, "indiv_params")
+
+    # threshold_csf
+    threshold_csf = NodeParams(fsl.Threshold(),
+                               params=parse_key(params, "threshold_csf"),
+                               name="threshold_csf")
+
+    seg_pipe.connect(register_csf_to_nat, 'out_file', threshold_csf, 'in_file')
+
+    seg_pipe.connect(
+        inputnode, ('indiv_params', parse_key, "threshold_csf"),
+        threshold_csf, "indiv_params")
 
     # outputnode
     outputnode = pe.Node(
@@ -450,9 +555,9 @@ def create_native_old_segment_pipe(params_template, params={},
             fields=["threshold_gm", "threshold_wm", "threshold_csf"]),
         name='outputnode')
 
-    seg_pipe.connect(thd_nodes["gm"], 'out_file', outputnode, 'threshold_gm')
-    seg_pipe.connect(thd_nodes["wm"], 'out_file', outputnode, 'threshold_wm')
-    seg_pipe.connect(thd_nodes["csf"], 'out_file', outputnode, 'threshold_csf')
+    seg_pipe.connect(threshold_gm, 'out_file', outputnode, 'threshold_gm')
+    seg_pipe.connect(threshold_wm, 'out_file', outputnode, 'threshold_wm')
+    seg_pipe.connect(threshold_csf, 'out_file', outputnode, 'threshold_csf')
 
     return seg_pipe
 
