@@ -80,7 +80,7 @@ from macapype.utils.misc import show_files, get_first_elem
 def create_main_workflow(data_dir, process_dir, soft, species, subjects, sessions,
                          acquisitions, reconstructions, params_file,
                          indiv_params_file, mask_file, nprocs,
-                         wf_name="test_pipeline_single",
+                         wf_name="macapype",
                          deriv=False, pad=False):
 
     # macapype_pipeline
@@ -125,6 +125,18 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
 
     soft = soft.lower()
 
+    ssoft = soft.split("_")
+
+    new_ssoft = ssoft.copy()
+    
+    if 'test' in ssoft:
+        new_ssoft.remove('test')
+        
+    if 'prep' in ssoft:
+        new_ssoft.remove('prep')
+        
+    soft = "_".join(new_ssoft)
+
     # formating args
     data_dir = op.abspath(data_dir)
 
@@ -172,24 +184,165 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
 
     params = json.load(open(params_file))
 
-    pprint.pprint(params)
-
     # indiv_params
     indiv_params = {}
-    if indiv_params_file is not None:
 
-        print("Indiv Params:", indiv_params_file)
+    if indiv_params_file is None:
 
-        assert os.path.exists(indiv_params_file), "Error with file {}".format(
-            indiv_params_file)
+        print("No indiv params where found, modifing pipepline to default")
+
+        if "short_preparation_pipe" in params.keys():
+            if "crop_T1" in params["short_preparation_pipe"].keys():
+                print("Deleting crop_T1")
+                del params["short_preparation_pipe"]["crop_T1"]
+
+                print("Adding automated bet_crop")
+
+                params["short_preparation_pipe"]["bet_crop"] = {"m": True, "aT2": True, "c": 10, "n": 2}
+
+                print("Using default bet_crop parameters: {}".format(
+                    params["short_preparation_pipe"]["bet_crop"]))
+
+                print("New params after modification")
+                pprint.pprint(params)
+
+                wf_name+="_bet_crop"
+
+    else:
 
         indiv_params = json.load(open(indiv_params_file))
 
         wf_name+="_indiv_params"
 
+        pprint.pprint(indiv_params)
 
-    pprint.pprint(indiv_params)
+        if "short_preparation_pipe" not in params.keys():
+            
+            print("short_preparation_pipe not found in params, not modifying preparation pipe")
+            
+        else:
 
+            prep_pipe = "short_preparation_pipe"
+            count_all_sessions=0
+            count_T1_crops=0
+            count_long_crops=0
+            count_multi_long_crops=0
+
+            print("Indiv Params:", indiv_params_file)
+
+            assert os.path.exists(indiv_params_file), "Error with file {}".format(
+                indiv_params_file)
+
+            if subjects is None or sessions is None:
+                print("For whole BIDS dir, unable to assess if the indiv_params is correct")
+                print("Running with params as it is")
+                
+            else:
+                    
+                print("Will modify params if necessary, given specified subjects and sessions;\n")
+                
+                for sub in indiv_params.keys():
+
+                    if sub.split('-')[1] not in subjects:
+                        continue
+
+                    for ses in indiv_params[sub].keys():
+
+                        if ses.split('-')[1] not in sessions:
+                            continue
+
+                        count_all_sessions+=1
+
+                        print (indiv_params[sub][ses].keys())
+
+                        if "crop_T1" in indiv_params[sub][ses].keys():
+                            count_T1_crops+=1
+
+                            if "crop_T2" in indiv_params[sub][ses].keys() \
+                                and 't1' not in ssoft:
+
+                                count_long_crops+=1
+
+                                if isinstance(
+                                    indiv_params[sub][ses]["crop_T1"]["args"],
+                                    list) and isinstance(
+                                        indiv_params[sub][ses]["crop_T2"]["args"],
+                                        list):
+
+                                    count_multi_long_crops+=1
+
+                print("count_all_sessions {}".format(count_all_sessions))
+
+                print("count_T1_crops {}".format(count_T1_crops))
+                print("count_long_crops {}".format(count_long_crops))
+                print("count_multi_long_crops {}".format(count_multi_long_crops))
+
+                if count_multi_long_crops==count_all_sessions:
+                    print("**** Found list of crops for T1 and T2 for all sub/ses \
+                        in indiv -> long_multi_preparation_pipe")
+
+                    wf_name+="_multi_crop_T1_T2"
+
+                    prep_pipe = "long_multi_preparation_pipe"
+
+                elif count_long_crops==count_all_sessions:
+
+                    print("**** Found crop for T1 and crop for T2 for all sub/ses \
+                        in indiv -> long_single_preparation_pipe")
+
+                    wf_name+="_crop_T1_T2"
+
+                    prep_pipe = "long_single_preparation_pipe"
+
+                elif count_T1_crops==count_all_sessions:
+
+                    print("**** Found crop for T1 for all sub/ses in indiv \
+                        -> keeping short_preparation_pipe")
+
+                    wf_name+="_crop_T1"
+
+                else:
+                    print("**** not all sub/ses have T1 and T2 crops ")
+                    print("Error")
+                    exit(0)
+
+                if prep_pipe != "short_preparation_pipe":
+
+                    params[prep_pipe]={
+                        "prep_T1": {"crop_T1": {"args": "should be defined in indiv"}},
+                        "prep_T2": {"crop_T2": {"args": "should be defined in indiv"}},
+                        "align_T2_on_T1": {"dof": 6, "cost": "normmi"}}
+
+                    if "norm_intensity" in params["short_preparation_pipe"].keys():
+                        norm_intensity= params["short_preparation_pipe"]["norm_intensity"]
+
+                        params[prep_pipe]["prep_T1"]["norm_intensity"]=norm_intensity
+                        params[prep_pipe]["prep_T2"]["norm_intensity"]=norm_intensity
+
+
+                    if "denoise" in params["short_preparation_pipe"].keys():
+                        denoise= params["short_preparation_pipe"]["denoise"]
+
+                        params[prep_pipe]["prep_T1"]["denoise"]=denoise
+                        params[prep_pipe]["prep_T2"]["denoise"]=denoise
+
+                    del params["short_preparation_pipe"]
+
+    # prep for testing only preparation part
+    if "prep" in ssoft:
+        print("Found prep in soft")
+        
+        if "brain_extraction_pipe" in params.keys():
+            del params["brain_extraction_pipe"]
+            print("Deleting brain_extraction_pipe")
+        
+            
+        if "brain_segment_pipe" in params.keys():
+            del params["brain_segment_pipe"]
+            print("Deleting brain_segment_pipe")
+            
+    pprint.pprint(params)
+            
     # params_template
     assert ("general" in params.keys() and \
         "template_name" in params["general"].keys()), \
@@ -212,8 +365,6 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
     if mask_file is not None:
          wf_name += "_mask"
 
-    ssoft = soft.lower().split("_")
-
     assert "spm" in ssoft or "spm12" in ssoft or "ants" in ssoft, \
         "error with {}, should be among [spm12, spm, ants]".format(ssoft)
 
@@ -351,14 +502,13 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
 
     if deriv:
 
-        datasink_name = os.path.join("derivatives", "macapype_{}".format(soft))
+        datasink_name = os.path.join("derivatives", "macapype_" + soft)
 
         if "regex_subs" in params.keys():
             params_regex_subs = params["regex_subs"]
         else:
             params_regex_subs={}
 
-
         if "subs" in params.keys():
             params_subs = params["rsubs"]
         else:
